from django.db.models.signals import post_save
from django.dispatch import receiver
from django_notifications.models import Notification
from django.conf import settings

models = settings.TRACKED_MODELS
TRACKED_MODELS = []
for el in models:
    app_label, model_name = el.split(".")
    TRACKED_MODELS.append(model_name)


def create_notification(sender, instance, created, **kwargs):
    if created:
        Notification.objects.create(
            app_name_model=instance._meta.model_name,
            app_name_ident=instance._meta.app_label,
            app_id_object=instance.id,
        )


# Динамически подписываем сигнал для каждой модели в TRACKED_MODELS
for model in TRACKED_MODELS:
    post_save.connect(create_notification, sender=model)

# Feedback(id, review_text, name, created_at, archived, is_approved, display_order)



from django.apps import AppConfig


class NotificationsConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_notifications"

    def ready(self):
        import django_notifications.signals



# Generated by Django 5.1.6 on 2025-02-28 13:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_notifications", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="notification",
            name="app_id_object",
            field=models.BigIntegerField(default=0),
        ),
    ]



from django.db import models


class Notification(models.Model):
    ident = models.BooleanField(default=True)
    app_name_model = models.TextField()
    app_name_ident = models.TextField()
    app_id_object = models.BigIntegerField(default=0)


from django.shortcuts import render, redirect

from django_notifications.models import Notification


def get_notifications(request):
    notification = Notification.objects.filter(ident=True).first()
    if not notification:
        return redirect('http://127.0.0.1:8000/admin/')
    url = f"http://127.0.0.1:8000/admin/{notification.app_name_ident}/{notification.app_name_model}/{notification.app_id_object}/change/"

    notification.ident = False
    notification.save()
    return redirect(url)



from django.urls import path

from django_notifications.views import get_notifications

app_name = 'django_notifications'

urlpatterns = [
    path('admin/django_notifications/', get_notifications, name='django_notifications'),
]



# Generated by Django 5.1.6 on 2025-02-28 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Notification",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("ident", models.BooleanField(default=True)),
                ("app_name_model", models.TextField()),
                ("app_name_ident", models.TextField()),
            ],
        ),
    ]
